        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
}
