        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,2,3,6,7,12,13,14,15,16,18,19,23,24,28,32,38,39,40,41,46,47,48,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 15 <br>5,9,10,11,20,25,29,30,31,34,35,42,43,44,45';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260430 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 12 <br>1,4,8,17,21,22,26,27,33,36,37,50';}
}
